@@ -119,6 +119,12 @@ function cggm_add_dynpoint($params, &$smarty)
       $map = $mod->GetPreference('default_map',0);
     }
   
+  if( !is_numeric($map) )
+    {
+      $mapobj = cggm_map_operations::load_by_name($map);
+      $map = $mapobj->id;
+    }
+
   if( !isset($params['name']) )
     {
       // name is required
@@ -218,7 +224,7 @@ class CGGoogleMaps extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '2.1.3';
+    return '2.2';
   }
 
 
@@ -357,6 +363,12 @@ EOT;
 
     $this->CreateParameter('maptemplate','',$this->Lang('help_param_maptemplate'));
     $this->SetParameterType('maptemplate',CLEAN_STRING);
+
+    $this->CreateParameter('zoomlevel','',$this->Lang('help_param_zoomlevel'));
+    $this->SetParameterType('zoomlevel',CLEAN_INT);
+
+    $this->CreateParameter('zoom_encompass','',$this->Lang('help_param_zoomencompass'));
+    $this->SetParameterType('zoom_encompass',CLEAN_INT);
   }
 
 
