@@ -21,6 +21,7 @@ $lang['cancel'] = 'Cancel';
 $lang['category_template'] = 'Category View Template';
 $lang['center_lat'] = 'Center Latitude';
 $lang['center_lon'] = 'Center Longitude';
+$lang['clearcache'] = 'Clear Geolocate Cache';
 $lang['click'] = 'Click';
 $lang['combine_points'] = 'Combine individual markers that are within range';
 $lang['combined_points_icon'] = 'Icon to use for combined points';
@@ -165,6 +166,8 @@ $lang['help_icon_url'] = 'Specify the URL to the pre-uploaded PNG image.  This i
 $lang['help_param_defer'] = 'Specify that all javascript tags should have the defer attribute set.  This may be useful for problems with IE7 and IE8 where Internet explorer tries to execute javascript on an incompletely rendered page.';
 $lang['help_param_map'] = 'Specify the ID or map name to use for laying out the google map.  If this parameter is not specified, the default map (if any) is used.';
 $lang['help_param_maptemplate'] = 'Specify the name of an existing, non default map template to use for this output.  If this parameter is not specified, the current default map template will be used';
+$lang['help_param_zoomlevel'] = '(integer) Allows overriding the zoom level stored with the map.  Valid values are from 1 to 17';
+$lang['help_param_zoomencompass'] = '(boolean) Allows overriding the zoom encompass setting that is stored with the map.';
 $lang['hide_directions'] = 'Hide Directions';
 $lang['horizontal_bar'] = 'Horizontal Bar';
 $lang['hybrid'] = 'Hybrid';
@@ -243,6 +246,7 @@ $lang['map_type'] = 'Map Type';
 $lang['metric'] = 'Metric';
 $lang['moddescription'] = 'A simple module for creating google maps';
 $lang['mouseover'] = 'MouseOver';
+$lang['msg_addresscache_cleared'] = 'Geolocation cache cleared';
 $lang['msg_categoryadded'] = 'Category Added';
 $lang['msg_categorydeleted'] = 'Category Deleted';
 $lang['msg_categoryupdated'] = 'Category Updated';
