@@ -9,8 +9,9 @@ $lang['aerial'] = 'A&eacute;rien';
 $lang['anchor_x'] = 'Localisation de l&#039;Ancre X Pixel';
 $lang['anchor_y'] = 'Localisation de l&#039;Ancre Y Pixel';
 $lang['apply'] = 'Appliquer';
-$lang['ask_delete_icon'] = '&Ecirc;tes vous certain de vouloir supprimer cette ic&ocirc;ne de la liste (aucun fichier sera supprim&eacute;)';
-$lang['ask_reset_icons'] = '&Ecirc;tes vous certain de vouloir supprimer toutes les ic&ocirc;nes et de revenir aux param&egrave;tres par d&eacute;faut ?';
+$lang['ask_delete_icon'] = '&Ecirc;tes vous certain(e) de vouloir supprimer cette ic&ocirc;ne de la liste (aucun fichier sera supprim&eacute;)';
+$lang['ask_reset_icons'] = '&Ecirc;tes vous certain(e) de vouloir supprimer toutes les ic&ocirc;nes et de revenir aux param&egrave;tres par d&eacute;faut ?';
+$lang['baloon_maptemplate'] = 'Gabarit du ballon';
 $lang['cancel'] = 'Annuler';
 $lang['category_template'] = 'Gabarit : vue de cat&eacute;gorie';
 $lang['center_lat'] = 'Latitude du centre ';
@@ -49,8 +50,8 @@ $lang['error_nameexists'] = 'Un objet avec ce m&ecirc;me nom existe d&eacute;j&a
 $lang['error_noapikey'] = 'La cl&eacute; Google Api est vide';
 $lang['error_noapikey2'] = 'La cl&eacute; Google Api est vide. Ce module ne fonctionnera pas correctement tant qu&#039;il ne sera pas param&eacute;tr&eacute; avec une cl&eacute; valide distribu&eacute;e par Google.';
 $lang['error_notfound'] = 'L&#039;objet demand&eacute; n&#039;a pas &eacute;t&eacute; trouv&eacute;';
-$lang['error_permissiondenied'] = 'Vous n&#039;avez pas les permissions necessaire pour excecuter cette action';
-$lang['friendlyname'] = 'Cartes Google Maps (Calguys)';
+$lang['error_permissiondenied'] = 'Vous n&#039;avez pas les permissions n&eacute;cessaire pour excecuter cette action';
+$lang['friendlyname'] = 'Cartes Google Maps (CG)';
 $lang['from'] = 'D&eacute;part';
 $lang['get_directions'] = 'Voir l&#039;itin&eacute;raire';
 $lang['google_api_key'] = 'Cl&eacute; Google API ';
@@ -62,7 +63,7 @@ $lang['help'] = '<h3>Que fait ce module ?</h3>
   <li>Flexible marker icon management.</li>
   <li>The ability to categorize markers.  Markers can belong to more than one category.</li>
   <li>Infowindow content can be specified using HTML</li>
-  <li>Streetview support</li>
+  <li>Support de Streetview</li>
   <li>The ability to display a sidebar of all markers associated with a map.</li>
   <li>The ability to display a category panel, and hide icons by unchecking a category checkbox.</li>
   <li>Directions support (either by displaying the route in the map (and with directions in a seperate panel), or by opening a new window</li>
@@ -82,19 +83,19 @@ $lang['help'] = '<h3>Que fait ce module ?</h3>
 </li>
 <li>Create a map.  Give the map a name, and adjust the paramters of the particular map to meet your liking.  Note that when resetting one of the map templates to defaults, you must still press the &amp;quot;Apply&amp;quot; or &amp;quot;Apply&amp;quot; buttons.</p>
 <li>Mark one of your maps as default, by clicking on the red &#039;X&#039; beside a particular map.  This is useful if you don&#039;t specify the &#039;map&#039; parameter on the tag.</li>
-<li>Create one or more points within the map, either by specifying a latitude and longitude, or with an address.</li>
-<li>Add the {CGGoogleMaps} tag inside the content block of a page, or inside a page template.  Then you&#039;re finished.</li>
+<li>Cr&eacute;ez un ou plusieurs points sur votre carte en cliquant sur l&#039;ic&ocirc;ne &quot;point&quot; soit en renseignant les coordonn&eacute;es g&eacute;ographiques (latitude et longitude) soit en renseignant l&#039;adresse.</li>
+<li>Ajoutez le tag {CGGoogleMaps} dans une page ou un gabarit. Vous avez termin&eacute;.</li>
 </ul>
 <br/>
-<h3>Ajouter manuellement des points &agrave; une carte</h3>
-<p>You can use smarty to add points to a module dynamically.  You can use this functionality to build a frappr like map with multiple points that are controlled dynamically from another module (like CompanyDirectory or FrontEndUsers).</p>
-<h4>The {cggm_add_dynpoint} Smarty Plugin</h4>
-<p>This smarty plugin <em>(only available when CGGoogleMaps is installed)</em> allows adding a point dynamically to a specified map.</p>
+<h3>Ajouter des points dynamiques &agrave; une carte</h3>
+<p>Vous pouvez utiliser Smarty pour ajouter des points dynamiques venant d&#039;un autre module. Par exemple, vous pouvez construire une carte de vos membres avec plusieurs points g&eacute;r&eacute;s par un autre module (comme CompanyDirectory, FrontEndUsers ou CGUserDirectory).</p>
+<h4>Le plugin Smarty {cggm_add_dynpoint}</h4>
+<p>Ce plugin Smarty <em>(disponible uniquement quand le module Cartes Google Maps est install&eacute;)</em> permet d&#039;ajouter des points dynamique sur une carte. Pour cela, ins&eacute;rez le code suivant dans un gabarit.</p>
 <h4>Utilisation :</h4>
-<pre><code>{cggm_add_dynpoint map=1 name=&#039;New York&#039; address=&#039;New York, NY&#039; icon=&#039;food&#039;}</code></pre><br/>
+<pre><code>{cggm_add_dynpoint map=1 name=&#039;Paris&#039; address=&#039;Paris, France&#039; icon=&#039;food&#039;}<br />{CGGoogleMaps map=&#039;1&#039;}</code></pre><br/>
 <h4>Param&egrave;tres :</h4>
   <ul> 
-<li><strong>requis</strong> - map : L&#039;ID (integer) de la carte &agrave; laquelle vous voulez ajouter le point</li>
+<li><strong>requis</strong> - map : l&#039;ID (integer) de la carte &agrave; laquelle vous voulez ajouter le point</li>
 <li><strong>requis</strong> - name : le nom du point &agrave; ajouter</li>
 <li><em>facultatif</em> - desc/description : le contenu HTML qui sera affich&eacute; dans la bo&icirc;te d&#039;information</li>
 <li><em>facultatif</em> - address : l&#039;adresse du lieu que vous ajoutez (vous devez mettre une adresse ou des param&egrave;tres de latitude et de longitude)</li>
@@ -102,11 +103,11 @@ $lang['help'] = '<h3>Que fait ce module ?</h3>
 <li><em>facultatif</em> - long : la longitude du point &agrave; ajouter</li>
 <li><em>facultatif</em> - category : A comma separated list of categories for this point (there is no need for the categories to already exists)</li>
 <li><em>facultatif</em> - tooltip : A tooltip to display when hovering over a point.</li>
-<li><em>facultatif</em> - icon : The name of an icon to use for this point.</li>
+<li><em>facultatif</em> - icon : le nom de l&#039;ic&ocirc;ne &agrave; utiliser pour ce point.</li>
   </ul>
 <br/>
-<p><strong>Note:</strong> Either the lat and long parameters must be specified, or the address.</p>
-<p><strong>Note:</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
+<p><strong>Note :</strong> Les coordonn&eacute;es g&eacute;ographiques (latitude/longitude) ou l&#039;adresse doivent imp&eacute;rativement &ecirc;tre renseign&eacute;s.</p>
+<p><strong>Note :</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
 </ul>
 <h3>Upgrade Information:</h3>
 <p><strong>Note:</strong> For people upgrading from CGGoogleMaps 1.x to the new 2.x series some work may need to be done, particularly if you have changed your map template, or are using custom options.  You may need to revise the styling of your map templates, and then update/save the values in the map settings.</p>
@@ -142,11 +143,13 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
 $lang['height'] = 'Hauteur ';
-$lang['help_anchor_location'] = '<strong>Remarque :</ strong>&nbsp;Le point d&#039;attache sp&eacute;cifie l&#039;emplacement en pixel (par rapport au coin sup&eacute;rieur gauche de l&#039;image), o&ugrave; l&#039;ic&ocirc;ne doit &ecirc;tre ancr&eacute;e au marqueur. Si aucune valeur n&#039;est sp&eacute;cifi&eacute;e, le centre de l&#039;ic&ocirc;ne sera utilis&eacute;e';
+$lang['help_anchor_location'] = '<strong>Remarque :</ strong>&nbsp;le point d&#039;attache sp&eacute;cifie l&#039;emplacement en pixel (par rapport au coin sup&eacute;rieur gauche de l&#039;image), o&ugrave; l&#039;ic&ocirc;ne doit &ecirc;tre ancr&eacute;e au marqueur. Si aucune valeur n&#039;est sp&eacute;cifi&eacute;e, le centre de l&#039;ic&ocirc;ne sera utilis&eacute;e';
 $lang['help_icon_url'] = 'Indiquez l&#039;URL de l&#039;image PNG pr&eacute;-t&eacute;l&eacute;charg&eacute;e. Cette image ne devrait pas &ecirc;tre plus grande que 32x32, et devrait supporter la transparence. L&#039;URL peut &ecirc;tre sp&eacute;cifi&eacute; par rapport &agrave; la racine de votre installation';
 $lang['help_param_defer'] = 'Indiquez que toutes les balises JavaScript doivent avoir l&#039;attribut defer positionn&eacute;. Cela peut &ecirc;tre utile pour des probl&egrave;mes avec IE7 et IE8 si Internet Explorer tente d&#039;ex&eacute;cuter du code JavaScript sur une page partiellement charg&eacute;e.';
 $lang['help_param_map'] = 'Indiquez l&#039;ID ou le nom de la carte &agrave; utiliser pour la pose de la carte google. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute;, la carte par d&eacute;faut (le cas &eacute;ch&eacute;ant) est utilis&eacute;e.';
 $lang['help_param_maptemplate'] = 'Indiquez le nom d&#039;un gabarit de carte existant -et non d&eacute;finit &quot;par d&eacute;faut&quot;- &agrave; utiliser pour cet affichage. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute;, le gabarit de carte par d&eacute;faut sera utilis&eacute;';
+$lang['help_param_zoomlevel'] = '(entier) Sp&eacute;cifie le niveau de zoom de la carte - outrepasse le param&egrave;tre de zoom de la carte. Valeurs : de 1 &agrave; 17';
+$lang['help_param_zoomencompass'] = '(bool&eacute;en) Sp&eacute;cifie si l&#039;entourage du zoom doit &ecirc;tre utilis&eacute; pour la carte';
 $lang['hide_directions'] = 'Masquer l&#039;itin&eacute;raire';
 $lang['horizontal_bar'] = 'Barre horizontale';
 $lang['hybrid'] = 'Hybride';
@@ -182,6 +185,8 @@ $lang['info_scalecontrols'] = 'Une &eacute;chelle peut &ecirc;tre afficher dans
 $lang['info_sensor'] = 'Certains navigateurs (notamment les navigateurs des smartphones) peuvent fournir des informations de latitude et longitude. Souhaitez-vous activer cette fonction ?';
 $lang['info_sidebar'] = 'Afficher une barre lat&eacute;rale pr&eacute;sentant la liste des points de la carte ?';
 $lang['info_sv_controls'] = 'Afficher les boutons &quot;StreetView&quot; (vue des photos des rues) sur la carte ?';
+$lang['info_sv_radius'] = 'Si Streetview est activ&eacute; pour une carte, &agrave; quelle distance (en m&egrave;tres) faut-il rechercher une situation valide de vue Streetview. Ceci est important dans les zones rurales o&ugrave; Streetview n&#039;est pas disponible dans toutes les rues.';
+$lang['info_sysdflt_baloon_template'] = 'Gabarit de bulle d&#039;informations par d&eacute;faut';
 $lang['info_sysdflt_category_template'] = 'Gabarit de liste des cat&eacute;gories par d&eacute;faut';
 $lang['info_sysdflt_dirform_template'] = 'Gabarit de saisie d&#039;itin&eacute;raire par d&eacute;faut';
 $lang['info_sysdflt_js_template'] = 'Gabarit Javascript par d&eacute;faut';
@@ -204,6 +209,7 @@ $lang['longitude'] = 'Longitude ';
 $lang['make_default'] = 'Faire de cette ic&ocirc;ne l&#039;ic&ocirc;ne par d&eacute;faut';
 $lang['marker_categories'] = 'Cat&eacute;gories de points';
 $lang['marker_icons'] = 'Ic&ocirc;nes de points';
+$lang['marker_skipped'] = 'La g&eacute;olocalisation (addresse en coordonn&eacute;es lat/long) a &eacute;chou&eacute; pour &quot;%s&quot;';
 $lang['map'] = 'Carte';
 $lang['maps'] = 'Cartes';
 $lang['maptemplate_addedit'] = 'Ajouter/Editer un gabarit de carte';
@@ -238,7 +244,7 @@ $lang['postuninstall'] = 'Le module Cartes Google Maps (CGGoogleMaps) et toutes
 $lang['preferences'] = 'Pr&eacute;f&eacute;rences';
 $lang['prompt_bounds_fudge'] = 'Agrandissement des limites de carte avec &quot;Entourage du zoom&quot;';
 $lang['prompt_categories'] = 'Categories ';
-$lang['prompt_directions'] = 'Itin&eacute;raires';
+$lang['prompt_directions'] = 'Itin&eacute;raire&nbsp;';
 $lang['prompt_from_here'] = 'Depuis ce point';
 $lang['prompt_icon_selection'] = 'S&eacute;lection d&#039;ic&ocirc;ne ';
 $lang['prompt_info_window'] = 'Afficher les bulles d&#039;informations ';
@@ -260,8 +266,9 @@ $lang['sidebar_template'] = 'Gabarit de panneau lat&eacute;ral';
 $lang['small'] = 'Petit';
 $lang['submit'] = 'Envoyer';
 $lang['sv_controls'] = 'Afficher les contr&ocirc;les StreetView (vue des rues) ';
+$lang['sv_radius'] = 'Rayon de recherche Streetview';
 $lang['tab_advanced'] = 'Avanc&eacute;';
-$lang['tab_directions'] = 'Itin&eacute;raires';
+$lang['tab_directions'] = 'Itin&eacute;raire&nbsp;';
 $lang['tab_jstemplate'] = 'Gabarit Javascript';
 $lang['tab_settings'] = 'Param&egrave;tres';
 $lang['tab_maptemplate'] = 'Gabarit de carte';
@@ -276,9 +283,8 @@ $lang['use_marker_icon'] = 'Pr&eacute;f&eacute;rer l&#039;ic&ocirc;ne du point';
 $lang['width'] = 'Largeur ';
 $lang['window'] = 'Fen&ecirc;tre';
 $lang['zoom_encompass'] = 'Entourage du zoom ';
-$lang['qca'] = 'P0-58741428-1276531635559';
-$lang['utma'] = '156861353.1249395224.1276535615.1291913802.1291929483.33';
-$lang['utmz'] = '156861353.1291929483.33.32.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
+$lang['utmz'] = '156861353.1317639646.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.1126794490.1317639646.1317639646.1317714526.2';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1291929483';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
