@@ -14,17 +14,13 @@ class cggm_map_generator
   private $_sidebar_items = array();  // a list of all sidebar items
   private $_meta = array();           // calculated metadata
   private $_errors = array();         // errors
+  private static $_instance = 0;      // instance generator.
 
-  public function __construct(cggm_map& $map,$api_key = '',$defer = false,$api_ver = '')
+  public function __construct(cggm_map& $map,$defer = false)
   {
+    self::$_instance++;
     $this->_map = $map;
-    $this->_api_key = $api_key;
     $this->_defer = $defer;
-
-    if( $api_ver != '' )
-      {
-	$this->_api_ver = $api_ver;
-      }
   }
 
 
@@ -42,35 +38,35 @@ class cggm_map_generator
     if( isset($this->_meta['center_lat']) ) return;
 
     // calculate minimum/maximum lat/long
-    $min_lat = 9999999;
-    $min_lon = 9999999;
-    $max_lat = -9999999;
-    $max_lon = -9999999;
+    $min_lat = 9999999.9;
+    $min_lon = 9999999.9;
+    $max_lat = -9999999.9;
+    $max_lon = -9999999.9;
     foreach( $this->_markers as $marker_name => $marker )
       {
-	$min_lat = min($marker->get_latitude(),$min_lat);
-	$min_lon = min($marker->get_longitude(),$min_lon);
-	$max_lat = max($marker->get_latitude(),$max_lat);
-	$max_lon = max($marker->get_longitude(),$max_lon);
+	$min_lat = (float)min($marker->get_latitude(),$min_lat);
+	$min_lon = (float)min($marker->get_longitude(),$min_lon);
+	$max_lat = (float)max($marker->get_latitude(),$max_lat);
+	$max_lon = (float)max($marker->get_longitude(),$max_lon);
       }
     // adjust min/max lat/long by bounds fudge
     $diff_lat = $max_lat - $min_lat;
     $diff_lon = $max_lon - $min_lon;
-    $min_lat -= $diff_lat * $this->_map->bounds_fudge;
-    $min_lon -= $diff_lon * $this->_map->bounds_fudge;
-    $max_lat += $diff_lat * $this->_map->bounds_fudge;
-    $max_lon += $diff_lon * $this->_map->bounds_fudge;
+    $min_lat -= $diff_lat * (float)$this->_map->bounds_fudge;
+    $min_lon -= $diff_lon * (float)$this->_map->bounds_fudge;
+    $max_lat += $diff_lat * (float)$this->_map->bounds_fudge;
+    $max_lon += $diff_lon * (float)$this->_map->bounds_fudge;
 
     // calculate the center.
     $center_lat = $min_lat + ($max_lat - $min_lat) / 2.0;
     $center_lon = $min_lon + ($max_lon - $min_lon) / 2.0;
 
-    $this->_meta['min_lat'] = $min_lat;
-    $this->_meta['min_lon'] = $min_lon;
-    $this->_meta['max_lat'] = $max_lat;
-    $this->_meta['max_lon'] = $max_lon;
-    $this->_meta['center_lat'] = $center_lat;
-    $this->_meta['center_lon'] = $center_lon;
+    $this->_meta['min_lat'] = (float)$min_lat;
+    $this->_meta['min_lon'] = (float)$min_lon;
+    $this->_meta['max_lat'] = (float)$max_lat;
+    $this->_meta['max_lon'] = (float)$max_lon;
+    $this->_meta['center_lat'] = (float)$center_lat;
+    $this->_meta['center_lon'] = (float)$center_lon;
   }
 
 
@@ -298,11 +294,11 @@ class cggm_map_generator
     $mod = cge_utils::get_module('CGGoogleMaps');
 
     $txt = '';
-    $txt .= '<div id="cggm_map_data_'.$map->get_id().'" style="display: none;">'."\n";
+    $txt .= '<div id="cggm_map_data_'.self::$_instance.'" style="display: none;">'."\n";
     $txt .= '<div class="cggm_map_markers" style="display: none;">'."\n";
     foreach( $this->_markers as $marker_name => $marker )
       {
-	$tmp = '<div class="cggm_marker" id="map_'.$map->get_id().'_marker_'.$marker_name.'">'."\n";
+	$tmp = '<div class="cggm_marker" id="map_'.self::$_instance.'_marker_'.$marker_name.'">'."\n";
 	$tmp .= '<input type="hidden" name="name" value="'.$marker_name.'"/>'."\n";
 	$tmp .= '<input type="hidden" name="title" value="'.cms_htmlentities($marker->get_title()).'"/>'."\n";
 	$tmp .= '<input type="hidden" name="latitude" value="'.$marker->get_latitude().'"/>'."\n";
@@ -342,7 +338,7 @@ class cggm_map_generator
 	  }
 
 	$tmp .= '<div class="cggm_infowindow_contents">'."\n";
-        $tmp .= '<div class="cggm_infowindow" id="cggm_map_infowindow_'.$map->get_id().'_'.$marker_name.'">'."\n".$description.'</div>'."\n";
+        $tmp .= '<div class="cggm_infowindow" id="cggm_map_infowindow_'.self::$_instance.'_'.$marker_name.'">'."\n".$description.'</div>'."\n";
 	$tmp .= "</div><!-- cggm_infowindow_contents -->\n";
 	$tmp .= "</div><!-- cggm_marker -->\n"; // close marker tag.
 	$txt .= $tmp;
@@ -350,7 +346,7 @@ class cggm_map_generator
 
     $txt .= "</div><!-- cggm_map_markers -->\n"; // close markers tag
     $txt .= "</div><!-- cggm_map_data -->\n"; // close data tag
-    $txt .= '<div id="cggm_infowindow_'.$map->get_id().'" style="position: absolute; left: -1000px;"></div>'."\n";
+    $txt .= '<div id="cggm_infowindow_'.self::$_instance.'" style="position: absolute; left: -1000px;"></div>'."\n";
     return $txt;
   }
 
@@ -409,7 +405,7 @@ class cggm_map_generator
     $smarty->assign('map_defertxt',$defertxt);
     $smarty->assign('msg_browser_incompatible',$mod->Lang('error_browser_incompatible'));
     $smarty->assign('msg_mapelem_notfound',$mod->Lang('error_mapelem_notfound'));
-    $smarty->assign('map_elem','map_'.$this->_map->get_id());
+    $smarty->assign('map_elem','map_'.self::$_instance);
 
     $template = $this->_map->get_js_template_name();
     if( $template )
@@ -437,6 +433,7 @@ class cggm_map_generator
     $map = $this->_map;
     $smarty = cmsms()->GetSmarty();
     $smarty->assign('map',$this->_map);
+    $smarty->assign('mapinstance',self::$_instance);
     $smarty->assign('generator',$this);
 
     $output = $this->generate_header();
