@@ -138,21 +138,21 @@ class cggm_marker
     if( $latitude != '' && $longitude != '' )
       {
 	$this->_address = '';
-	$this->_lat = $latitude;
-	$this->_long = $longitude;
+	$this->_lat = (float)$latitude;
+	$this->_long = (float)$longitude;
       }
   }
 
 
   public function get_latitude()
   {
-    return $this->_lat;
+    return (float)$this->_lat;
   }
 
 
   public function get_longitude()
   {
-    return $this->_long;
+    return (float)$this->_long;
   }
 
 
